Struct Coiflet
pub struct Coiflet { /* private fields */ }Expand description
Coiflet wavelet family
Coiflets are a family of wavelets designed by Ingrid Daubechies at the request of Ronald Coifman. The wavelet function has 2N vanishing moments and the scaling function has 2N-1 vanishing moments. They are more symmetrical than Daubechies wavelets.
Implementations